# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ......core.datetime_utils import serialize_datetime

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Vitals(pydantic.BaseModel):
    """
    from candid.resources.encounters.v_4 import Vitals

    Vitals(
        height_in=70,
        weight_lbs=165,
        blood_pressure_systolic_mmhg=115,
        blood_pressure_diastolic_mmhg=85,
        body_temperature_f=98.0,
    )
    """

    height_in: int
    weight_lbs: int
    blood_pressure_systolic_mmhg: int
    blood_pressure_diastolic_mmhg: int
    body_temperature_f: typing.Optional[float] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PhoneNumberType(str, enum.Enum):
    HOME = "Home"
    MOBILE = "Mobile"
    WORK = "Work"

    def visit(
        self,
        home: typing.Callable[[], T_Result],
        mobile: typing.Callable[[], T_Result],
        work: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is PhoneNumberType.HOME:
            return home()
        if self is PhoneNumberType.MOBILE:
            return mobile()
        if self is PhoneNumberType.WORK:
            return work()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from ...commons.types.date import Date
from ...commons.types.street_address_short_zip import StreetAddressShortZip
from .individual_base import IndividualBase

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class PatientBase(IndividualBase):
    external_id: str = pydantic.Field(
        description="The ID used to identify this individual in your system. For example, your internal patient ID or an EHR patient ID."
    )
    date_of_birth: Date = pydantic.Field(
        description="Box 3 on the CMS-1500 claim form. The date format should be in ISO 8601 date; formatted YYYY-MM-DD (i.e. 2012-02-01)"
    )
    address: StreetAddressShortZip = pydantic.Field(description="Box 5 on the CMS-1500 claim form.")

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.cash_pay_payer_error_message import CashPayPayerErrorMessage


class CashPayPayerError(ApiError):
    def __init__(self, body: CashPayPayerErrorMessage):
        super().__init__(status_code=422, body=body)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ......core.datetime_utils import serialize_datetime
from .....commons.types.rate_id import RateId
from .....commons.types.user_id import UserId
from .dimensions import Dimensions
from .rate_entry import RateEntry

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Rate(pydantic.BaseModel):
    """
    A comprehensive rate including the current rate value and all values for historic time ranges. The time ranges specified by each RateEntry are disjoint. A rate must always have at least one entry.
    """

    rate_id: RateId
    dimensions: Dimensions = pydantic.Field(description="The dimension values that distinguish this rate from others.")
    version: int = pydantic.Field(description="The version of this rate in the system.")
    updated_at: dt.date
    updated_by: UserId
    entries: typing.List[RateEntry]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .new_rate import NewRate
from .new_rate_version import NewRateVersion


class RateUpload_NewRate(NewRate):
    type: typing_extensions.Literal["new_rate"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class RateUpload_NewVersion(NewRateVersion):
    type: typing_extensions.Literal["new_version"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


RateUpload = typing.Union[RateUpload_NewRate, RateUpload_NewVersion]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ......core.datetime_utils import serialize_datetime
from .lab_code_type import LabCodeType

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Lab(pydantic.BaseModel):
    """
    from candid.resources.encounters.v_4 import Lab, LabCodeType

    Lab(
        name="Genetic Health Labs",
        code="GH12345",
        code_type=LabCodeType.QUEST,
    )
    """

    name: str
    code: typing.Optional[str] = None
    code_type: typing.Optional[LabCodeType] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .....commons.types.entity_conflict_error_message import EntityConflictErrorMessage
from .....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from .overlapping_rate_entries_error import OverlappingRateEntriesError

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class ValidationError_OverlappingRateEntries(OverlappingRateEntriesError):
    type: typing_extensions.Literal["overlapping_rate_entries"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class ValidationError_VersionConflict(EntityConflictErrorMessage):
    type: typing_extensions.Literal["version_conflict"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class ValidationError_OrganizationProviderNotFound(EntityNotFoundErrorMessage):
    type: typing_extensions.Literal["organization_provider_not_found"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class ValidationError_DuplicateRate(pydantic.BaseModel):
    type: typing_extensions.Literal["duplicate_rate"]

    class Config:
        frozen = True
        smart_union = True


class ValidationError_EmptyEntries(pydantic.BaseModel):
    type: typing_extensions.Literal["empty_entries"]

    class Config:
        frozen = True
        smart_union = True


ValidationError = typing.Union[
    ValidationError_OverlappingRateEntries,
    ValidationError_VersionConflict,
    ValidationError_OrganizationProviderNotFound,
    ValidationError_DuplicateRate,
    ValidationError_EmptyEntries,
]
